@@ -40,7 +40,7 @@ static bool is_functions_list_matching(zend_execute_data* execute_data,
                                        sp_list_node* functions_list) {
   zend_execute_data *orig_execute_data, *current;
   orig_execute_data = current = execute_data;
-  sp_list_node* it = functions_list;
+  sp_list_node const* it = functions_list;
 
   while (current) {
     if (it == NULL) {  // every function in the list matched, we've got a match!
@@ -50,7 +50,7 @@ static bool is_functions_list_matching(zend_execute_data* execute_data,
 
     EG(current_execute_data) = current;
 
-    char* complete_path_function = get_complete_function_path(current);
+    char* const complete_path_function = get_complete_function_path(current);
     if (!complete_path_function) {
       break;
     }
@@ -59,10 +59,8 @@ static bool is_functions_list_matching(zend_execute_data* execute_data,
 
     if (0 == match) {
       it = it->next;
-      current = current->prev_execute_data;
-    } else {
-      break;
     }
+    current = current->prev_execute_data;
   }
 
   EG(current_execute_data) = orig_execute_data;
@@ -628,7 +626,11 @@ int hook_disabled_functions(void) {
 
 zend_write_func_t zend_write_default = NULL;
 
+#if PHP_VERSION_ID >= 80000
+size_t hook_echo(const char* str, size_t str_length) {
+#else
 int hook_echo(const char* str, size_t str_length) {
+#endif
   zend_string* zs = zend_string_init(str, str_length, 0);
 
   should_disable_ht(
